/* generated using openapi-typescript-codegen -- do no edit */
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { ResourceVersionIn } from '../models/ResourceVersionIn';
import type { ResourceVersionOut } from '../models/ResourceVersionOut';
import type { Status } from '../models/Status';
import type { CancelablePromise } from '../core/CancelablePromise';
import { OpenAPI } from '../core/OpenAPI';
import { request as __request } from '../core/request';
export class ResourceVersionService {
    /**
     * List versions of a resource
     * List all the resource version for a specific resource.
     *
     * Permission 'resource:read' required.
     * @param rid
     * @param versionStatus Which versions to include in the response. Permission `resource:read_any` required, current user is the maintainer, then only permission `resource:read` required. Default `LATEST` and `SYNCHRONIZED`.
     * @returns ResourceVersionOut Successful Response
     * @throws ApiError
     */
    public static resourceVersionListResourceVersions(
        rid: string,
        versionStatus?: Array<Status>,
    ): CancelablePromise<Array<ResourceVersionOut>> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/resources/{rid}/versions',
            path: {
                'rid': rid,
            },
            query: {
                'version_status': versionStatus,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * Request new version of a resource
     * Request a new resource version.
     *
     * Permission `resource:update` required if the current user is the maintainer, `resource:update_any` otherwise.
     * @param rid
     * @param requestBody
     * @returns ResourceVersionOut Successful Response
     * @throws ApiError
     */
    public static resourceVersionRequestResourceVersion(
        rid: string,
        requestBody: ResourceVersionIn,
    ): CancelablePromise<ResourceVersionOut> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/resources/{rid}/versions',
            path: {
                'rid': rid,
            },
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * Get version of a resource
     * Get a specific resource version for a specific resource.
     *
     * Permission `resource:read` required. If the status of the resource version is not `LATEST` or `SYNCHRONIZED` and
     * the current user is not the maintainer, then the permission `resource:read_any` is required.
     * @param rid
     * @param rvid
     * @returns ResourceVersionOut Successful Response
     * @throws ApiError
     */
    public static resourceVersionGetResourceVersion(
        rid: string,
        rvid: string,
    ): CancelablePromise<ResourceVersionOut> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/resources/{rid}/versions/{rvid}',
            path: {
                'rid': rid,
                'rvid': rvid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * Request resource version synchronization
     * Request the synchronization of a resource version to the cluster.
     *
     * Permission `resource:request_sync` required if current user is the maintainer, `resource:request_sync_any` otherwise.
     * @param rid
     * @param rvid
     * @returns ResourceVersionOut Successful Response
     * @throws ApiError
     */
    public static resourceVersionRequestResourceVersionSync(
        rid: string,
        rvid: string,
    ): CancelablePromise<ResourceVersionOut> {
        return __request(OpenAPI, {
            method: 'PUT',
            url: '/resources/{rid}/versions/{rvid}/request_sync',
            path: {
                'rid': rid,
                'rvid': rvid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * Synchronize resource version with cluster
     * Synchronize the resource version to the cluster.
     *
     * Permission `resource:sync` required.
     * @param rid
     * @param rvid
     * @returns ResourceVersionOut Successful Response
     * @throws ApiError
     */
    public static resourceVersionResourceVersionSync(
        rid: string,
        rvid: string,
    ): CancelablePromise<ResourceVersionOut> {
        return __request(OpenAPI, {
            method: 'PUT',
            url: '/resources/{rid}/versions/{rvid}/sync',
            path: {
                'rid': rid,
                'rvid': rvid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * Set resource version to latest
     * Set the resource version as the latest version.
     *
     * Permission `resource:set_latest` required.
     * @param rid
     * @param rvid
     * @returns ResourceVersionOut Successful Response
     * @throws ApiError
     */
    public static resourceVersionResourceVersionLatest(
        rid: string,
        rvid: string,
    ): CancelablePromise<ResourceVersionOut> {
        return __request(OpenAPI, {
            method: 'PUT',
            url: '/resources/{rid}/versions/{rvid}/latest',
            path: {
                'rid': rid,
                'rvid': rvid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * Delete resource version on cluster
     * Delete the resource version on the cluster.
     *
     * Permission `resource:delete_cluster` required.
     * @param rid
     * @param rvid
     * @returns ResourceVersionOut Successful Response
     * @throws ApiError
     */
    public static resourceVersionDeleteResourceVersionCluster(
        rid: string,
        rvid: string,
    ): CancelablePromise<ResourceVersionOut> {
        return __request(OpenAPI, {
            method: 'DELETE',
            url: '/resources/{rid}/versions/{rvid}/cluster',
            path: {
                'rid': rid,
                'rvid': rvid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
    /**
     * Delete resource version in S3
     * Delete the resource version in the S3 bucket.
     *
     * Permission `resource:delete_s3` required.
     * @param rid
     * @param rvid
     * @returns ResourceVersionOut Successful Response
     * @throws ApiError
     */
    public static resourceVersionDeleteResourceVersionS3(
        rid: string,
        rvid: string,
    ): CancelablePromise<ResourceVersionOut> {
        return __request(OpenAPI, {
            method: 'DELETE',
            url: '/resources/{rid}/versions/{rvid}/s3',
            path: {
                'rid': rid,
                'rvid': rvid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }
}
