import type { RouteRecordRaw } from "vue-router";

export const workflowRoutes: RouteRecordRaw[] = [
  {
    path: "workflow-executions",
    name: "workflow-executions",
    component: () =>
      import("../views/workflows/ListWorkflowExecutionsView.vue"),
  },
  {
    path: "workflows",
    name: "workflows",
    component: () => import("../views/workflows/ListWorkflowsView.vue"),
  },
  {
    path: "developer/workflows",
    name: "workflows-developer",
    component: () => import("../views/workflows/MyWorkflowsView.vue"),
    meta: {
      requiresDeveloperRole: true,
    },
  },
  {
    path: "reviewer/workflows",
    name: "workflows-reviewer",
    component: () => import("../views/workflows/ReviewWorkflowsView.vue"),
    meta: {
      requiresReviewerRole: true,
    },
  },
  {
    path: "workflows/arbitrary",
    name: "arbitrary-workflow",
    component: () => import("../views/workflows/ArbitraryWorkflowView.vue"),
    meta: {
      requiresDeveloperRole: true,
    },
    props: (route) => ({
      wid: route.query.wid,
    }),
  },
  {
    path: "workflows/:workflowId",
    name: "workflow",
    component: () => import("../views/workflows/WorkflowView.vue"),
    props: (route) => ({
      versionId: route.params.versionId ?? undefined,
      workflowId: route.params.workflowId,
      workflowModeId: route.query.workflowModeId ?? undefined,
      developerView: route.query.developerView == "true",
    }),
    children: [
      {
        path: "version/:versionId",
        name: "workflow-version",
        component: () => import("../views/workflows/WorkflowVersionView.vue"),
        props: (route) => ({
          versionId: route.params.versionId,
          workflowId: route.params.workflowId,
          activeTab: route.query.tab ?? "description",
          workflowModeId: route.query.workflowModeId ?? undefined,
        }),
      },
      {
        path: "version/:versionId/start",
        name: "workflow-start",
        component: () => import("../views/workflows/StartWorkflowView.vue"),
        props: (route) => ({
          versionId: route.params.versionId,
          workflowId: route.params.workflowId,
          workflowModeId: route.query.workflowModeId ?? undefined,
        }),
      },
    ],
  },
];
